/****************************************************************************
 * boards/arm64/imx9/imx93-evk/include/imx9_ddr_training.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

#ifndef __BOARDS_ARM64_IMX9_IMX93_EVK_INCLUDE_IMX9_DDR_TRAINING_H
#define __BOARDS_ARM64_IMX9_IMX93_EVK_INCLUDE_IMX9_DDR_TRAINING_H

/****************************************************************************
 * Pre-processor Definitions
 ****************************************************************************/

#define FILE_DMEM_1D "ddr/firmware-imx-8.23/firmware/ddr/synopsys/lpddr4_dmem_1d_v202201.bin"
#define FILE_DMEM_2D "ddr/firmware-imx-8.23/firmware/ddr/synopsys/lpddr4_dmem_2d_v202201.bin"

#define FILE_IMEM_1D "ddr/firmware-imx-8.23/firmware/ddr/synopsys/lpddr4_imem_1d_v202201.bin"
#define FILE_IMEM_2D "ddr/firmware-imx-8.23/firmware/ddr/synopsys/lpddr4_imem_2d_v202201.bin"

static struct dram_fsp_cfg ddr_dram_fsp_cfg[] =
{
  {
    {
      { IMX9_DDRC_TIMING_CFG_3,   0x24ab321b },
      { IMX9_DDRC_TIMING_CFG_0,   0xf8ee001b },
      { IMX9_DDRC_TIMING_CFG_1,   0x2f2ee233 },
      { IMX9_DDRC_TIMING_CFG_2,   0x0005c18b },
      { IMX9_DDRC_SDRAM_INTERVAL, 0x1c790000 },
      { IMX9_DDRC_TIMING_CFG_4,   0x00009102 },
      { IMX9_DDRC_TIMING_CFG_7,   0x35f00000 },
      { IMX9_DDRC_ZQ_CNTL,        0x8b0b0608 },
      { IMX9_DDRC_TIMING_CFG_8,   0x00000028 },
      { IMX9_DDRC_TIMING_CFG_9,   0x015b015b },
      { IMX9_DDRC_TIMING_CFG_10,  0x00000008 },
      { IMX9_DDRC_TIMING_CFG_11,  0x00000400 },
      { IMX9_DDRC_TIMING_CFG_12,  0x224f2213 },
      { IMX9_DDRC_TIMING_CFG_13,  0x015b2213 },
      { IMX9_DDRC_TIMING_CFG_14,  0x0a380e3d },
    },
    {
      { 0x01, 0xe4 },
      { 0x02, 0x36 },
      { 0x03, 0x32 },
      { 0x0b, 0x46 },
      { 0x0c, 0x11 },
      { 0x0e, 0x11 },
      { 0x16, 0x04 },
    },
    0,
  },
};

/* PHY Initialize Configuration */

static struct dram_cfg_param ddr_ddrphy_cfg[] =
{
  { 0x100a0, 0x4 },
  { 0x100a1, 0x5 },
  { 0x100a2, 0x6 },
  { 0x100a3, 0x7 },
  { 0x100a4, 0x0 },
  { 0x100a5, 0x1 },
  { 0x100a6, 0x2 },
  { 0x100a7, 0x3 },
  { 0x110a0, 0x3 },
  { 0x110a1, 0x2 },
  { 0x110a2, 0x0 },
  { 0x110a3, 0x1 },
  { 0x110a4, 0x7 },
  { 0x110a5, 0x6 },
  { 0x110a6, 0x4 },
  { 0x110a7, 0x5 },
  { 0x1005f, 0x5ff },
  { 0x1015f, 0x5ff },
  { 0x1105f, 0x5ff },
  { 0x1115f, 0x5ff },
  { 0x55, 0x1ff },
  { 0x1055, 0x1ff },
  { 0x2055, 0x1ff },
  { 0x200c5, 0x19 },
  { 0x2002e, 0x2 },
  { 0x90204, 0x0 },
  { 0x20024, 0x1e3 },
  { 0x2003a, 0x2 },
  { 0x2007d, 0x212 },
  { 0x2007c, 0x61 },
  { 0x20056, 0x3 },
  { 0x1004d, 0x600 },
  { 0x1014d, 0x600 },
  { 0x1104d, 0x600 },
  { 0x1114d, 0x600 },
  { 0x10049, 0xe00 },
  { 0x10149, 0xe00 },
  { 0x11049, 0xe00 },
  { 0x11149, 0xe00 },
  { 0x43, 0x60 },
  { 0x1043, 0x60 },
  { 0x2043, 0x60 },
  { 0x20018, 0x1 },
  { 0x20075, 0x4 },
  { 0x20050, 0x0 },
  { 0x2009b, 0x2 },
  { 0x20008, 0x3a5 },
  { 0x20088, 0x9 },
  { 0x200b2, 0x10c },
  { 0x10043, 0x5a1 },
  { 0x10143, 0x5a1 },
  { 0x11043, 0x5a1 },
  { 0x11143, 0x5a1 },
  { 0x200fa, 0x2 },
  { 0x20019, 0x1 },
  { 0x200f0, 0x500 },
  { 0x200f1, 0x0 },
  { 0x200f2, 0x4444 },
  { 0x200f3, 0x8888 },
  { 0x200f4, 0x5555 },
  { 0x200f5, 0x0 },
  { 0x200f6, 0x0 },
  { 0x200f7, 0xf000 },
  { 0x1004a, 0x500 },
  { 0x1104a, 0x500 },
  { 0x20025, 0x0 },
  { 0x2002d, 0x0 },
  { 0x2002c, 0x0 },
  { 0x20021, 0x0 },
  { 0x200c7, 0x21 },
  { 0x1200c7, 0x21 },
  { 0x200ca, 0x24 },
  { 0x1200ca, 0x24 },
};

/* P0 message block parameter for training firmware */

static struct dram_cfg_param ddr_fsp0_cfg[] =
{
  { 0xd0000, 0x0 },
  { 0x54003, 0xe94 },
  { 0x54004, 0x4 },
  { 0x54006, 0x15 },
  { 0x54008, 0x131f },
  { 0x54009, 0xc8 },
  { 0x5400b, 0x4 },
  { 0x5400d, 0x100 },
  { 0x5400f, 0x100 },
  { 0x54012, 0x110 },
  { 0x54019, 0x36e4 },
  { 0x5401a, 0x32 },
  { 0x5401b, 0x1146 },
  { 0x5401c, 0x1108 },
  { 0x5401e, 0x4 },
  { 0x5401f, 0x36e4 },
  { 0x54020, 0x32 },
  { 0x54021, 0x1146 },
  { 0x54022, 0x1108 },
  { 0x54024, 0x4 },
  { 0x54032, 0xe400 },
  { 0x54033, 0x3236 },
  { 0x54034, 0x4600 },
  { 0x54035, 0x811 },
  { 0x54036, 0x11 },
  { 0x54037, 0x400 },
  { 0x54038, 0xe400 },
  { 0x54039, 0x3236 },
  { 0x5403a, 0x4600 },
  { 0x5403b, 0x811 },
  { 0x5403c, 0x11 },
  { 0x5403d, 0x400 },
  { 0xd0000, 0x1 }
};

/* P0 2D message block parameter for training firmware */

static struct dram_cfg_param ddr_fsp0_2d_cfg[] =
{
  { 0xd0000, 0x0 },
  { 0x54003, 0xe94 },
  { 0x54004, 0x4 },
  { 0x54006, 0x15 },
  { 0x54008, 0x61 },
  { 0x54009, 0xc8 },
  { 0x5400b, 0x4 },
  { 0x5400d, 0x100 },
  { 0x5400f, 0x100 },
  { 0x54010, 0x2080 },
  { 0x54012, 0x110 },
  { 0x54019, 0x36e4 },
  { 0x5401a, 0x32 },
  { 0x5401b, 0x1146 },
  { 0x5401c, 0x1108 },
  { 0x5401e, 0x4 },
  { 0x5401f, 0x36e4 },
  { 0x54020, 0x32 },
  { 0x54021, 0x1146 },
  { 0x54022, 0x1108 },
  { 0x54024, 0x4 },
  { 0x54032, 0xe400 },
  { 0x54033, 0x3236 },
  { 0x54034, 0x4600 },
  { 0x54035, 0x811 },
  { 0x54036, 0x11 },
  { 0x54037, 0x400 },
  { 0x54038, 0xe400 },
  { 0x54039, 0x3236 },
  { 0x5403a, 0x4600 },
  { 0x5403b, 0x811 },
  { 0x5403c, 0x11 },
  { 0x5403d, 0x400 },
  { 0xd0000, 0x1 }
};

/* DRAM PHY init engine image */

static struct dram_cfg_param ddr_phy_pie[] =
{
  { 0xd0000, 0x0 },
  { 0x90000, 0x10 },
  { 0x90001, 0x400 },
  { 0x90002, 0x10e },
  { 0x90003, 0x0 },
  { 0x90004, 0x0 },
  { 0x90005, 0x8 },
  { 0x90029, 0xb },
  { 0x9002a, 0x480 },
  { 0x9002b, 0x109 },
  { 0x9002c, 0x8 },
  { 0x9002d, 0x448 },
  { 0x9002e, 0x139 },
  { 0x9002f, 0x8 },
  { 0x90030, 0x478 },
  { 0x90031, 0x109 },
  { 0x90032, 0x0 },
  { 0x90033, 0xe8 },
  { 0x90034, 0x109 },
  { 0x90035, 0x2 },
  { 0x90036, 0x10 },
  { 0x90037, 0x139 },
  { 0x90038, 0xb },
  { 0x90039, 0x7c0 },
  { 0x9003a, 0x139 },
  { 0x9003b, 0x44 },
  { 0x9003c, 0x633 },
  { 0x9003d, 0x159 },
  { 0x9003e, 0x14f },
  { 0x9003f, 0x630 },
  { 0x90040, 0x159 },
  { 0x90041, 0x47 },
  { 0x90042, 0x633 },
  { 0x90043, 0x149 },
  { 0x90044, 0x4f },
  { 0x90045, 0x633 },
  { 0x90046, 0x179 },
  { 0x90047, 0x8 },
  { 0x90048, 0xe0 },
  { 0x90049, 0x109 },
  { 0x9004a, 0x0 },
  { 0x9004b, 0x7c8 },
  { 0x9004c, 0x109 },
  { 0x9004d, 0x0 },
  { 0x9004e, 0x1 },
  { 0x9004f, 0x8 },
  { 0x90050, 0x30 },
  { 0x90051, 0x65a },
  { 0x90052, 0x9 },
  { 0x90053, 0x0 },
  { 0x90054, 0x45a },
  { 0x90055, 0x9 },
  { 0x90056, 0x0 },
  { 0x90057, 0x448 },
  { 0x90058, 0x109 },
  { 0x90059, 0x40 },
  { 0x9005a, 0x633 },
  { 0x9005b, 0x179 },
  { 0x9005c, 0x1 },
  { 0x9005d, 0x618 },
  { 0x9005e, 0x109 },
  { 0x9005f, 0x40c0 },
  { 0x90060, 0x633 },
  { 0x90061, 0x149 },
  { 0x90062, 0x8 },
  { 0x90063, 0x4 },
  { 0x90064, 0x48 },
  { 0x90065, 0x4040 },
  { 0x90066, 0x633 },
  { 0x90067, 0x149 },
  { 0x90068, 0x0 },
  { 0x90069, 0x4 },
  { 0x9006a, 0x48 },
  { 0x9006b, 0x40 },
  { 0x9006c, 0x633 },
  { 0x9006d, 0x149 },
  { 0x9006e, 0x0 },
  { 0x9006f, 0x658 },
  { 0x90070, 0x109 },
  { 0x90071, 0x10 },
  { 0x90072, 0x4 },
  { 0x90073, 0x18 },
  { 0x90074, 0x0 },
  { 0x90075, 0x4 },
  { 0x90076, 0x78 },
  { 0x90077, 0x549 },
  { 0x90078, 0x633 },
  { 0x90079, 0x159 },
  { 0x9007a, 0xd49 },
  { 0x9007b, 0x633 },
  { 0x9007c, 0x159 },
  { 0x9007d, 0x94a },
  { 0x9007e, 0x633 },
  { 0x9007f, 0x159 },
  { 0x90080, 0x441 },
  { 0x90081, 0x633 },
  { 0x90082, 0x149 },
  { 0x90083, 0x42 },
  { 0x90084, 0x633 },
  { 0x90085, 0x149 },
  { 0x90086, 0x1 },
  { 0x90087, 0x633 },
  { 0x90088, 0x149 },
  { 0x90089, 0x0 },
  { 0x9008a, 0xe0 },
  { 0x9008b, 0x109 },
  { 0x9008c, 0xa },
  { 0x9008d, 0x10 },
  { 0x9008e, 0x109 },
  { 0x9008f, 0x9 },
  { 0x90090, 0x3c0 },
  { 0x90091, 0x149 },
  { 0x90092, 0x9 },
  { 0x90093, 0x3c0 },
  { 0x90094, 0x159 },
  { 0x90095, 0x18 },
  { 0x90096, 0x10 },
  { 0x90097, 0x109 },
  { 0x90098, 0x0 },
  { 0x90099, 0x3c0 },
  { 0x9009a, 0x109 },
  { 0x9009b, 0x18 },
  { 0x9009c, 0x4 },
  { 0x9009d, 0x48 },
  { 0x9009e, 0x18 },
  { 0x9009f, 0x4 },
  { 0x900a0, 0x58 },
  { 0x900a1, 0xb },
  { 0x900a2, 0x10 },
  { 0x900a3, 0x109 },
  { 0x900a4, 0x1 },
  { 0x900a5, 0x10 },
  { 0x900a6, 0x109 },
  { 0x900a7, 0x5 },
  { 0x900a8, 0x7c0 },
  { 0x900a9, 0x109 },
  { 0x40000, 0x811 },
  { 0x40020, 0x880 },
  { 0x40040, 0x0 },
  { 0x40060, 0x0 },
  { 0x40001, 0x4008 },
  { 0x40021, 0x83 },
  { 0x40041, 0x4f },
  { 0x40061, 0x0 },
  { 0x40002, 0x4040 },
  { 0x40022, 0x83 },
  { 0x40042, 0x51 },
  { 0x40062, 0x0 },
  { 0x40003, 0x811 },
  { 0x40023, 0x880 },
  { 0x40043, 0x0 },
  { 0x40063, 0x0 },
  { 0x40004, 0x720 },
  { 0x40024, 0xf },
  { 0x40044, 0x1740 },
  { 0x40064, 0x0 },
  { 0x40005, 0x16 },
  { 0x40025, 0x83 },
  { 0x40045, 0x4b },
  { 0x40065, 0x0 },
  { 0x40006, 0x716 },
  { 0x40026, 0xf },
  { 0x40046, 0x2001 },
  { 0x40066, 0x0 },
  { 0x40007, 0x716 },
  { 0x40027, 0xf },
  { 0x40047, 0x2800 },
  { 0x40067, 0x0 },
  { 0x40008, 0x716 },
  { 0x40028, 0xf },
  { 0x40048, 0xf00 },
  { 0x40068, 0x0 },
  { 0x40009, 0x720 },
  { 0x40029, 0xf },
  { 0x40049, 0x1400 },
  { 0x40069, 0x0 },
  { 0x4000a, 0xe08 },
  { 0x4002a, 0xc15 },
  { 0x4004a, 0x0 },
  { 0x4006a, 0x0 },
  { 0x4000b, 0x625 },
  { 0x4002b, 0x15 },
  { 0x4004b, 0x0 },
  { 0x4006b, 0x0 },
  { 0x4000c, 0x4028 },
  { 0x4002c, 0x80 },
  { 0x4004c, 0x0 },
  { 0x4006c, 0x0 },
  { 0x4000d, 0xe08 },
  { 0x4002d, 0xc1a },
  { 0x4004d, 0x0 },
  { 0x4006d, 0x0 },
  { 0x4000e, 0x625 },
  { 0x4002e, 0x1a },
  { 0x4004e, 0x0 },
  { 0x4006e, 0x0 },
  { 0x4000f, 0x4040 },
  { 0x4002f, 0x80 },
  { 0x4004f, 0x0 },
  { 0x4006f, 0x0 },
  { 0x40010, 0x2604 },
  { 0x40030, 0x15 },
  { 0x40050, 0x0 },
  { 0x40070, 0x0 },
  { 0x40011, 0x708 },
  { 0x40031, 0x5 },
  { 0x40051, 0x0 },
  { 0x40071, 0x2002 },
  { 0x40012, 0x8 },
  { 0x40032, 0x80 },
  { 0x40052, 0x0 },
  { 0x40072, 0x0 },
  { 0x40013, 0x2604 },
  { 0x40033, 0x1a },
  { 0x40053, 0x0 },
  { 0x40073, 0x0 },
  { 0x40014, 0x708 },
  { 0x40034, 0xa },
  { 0x40054, 0x0 },
  { 0x40074, 0x2002 },
  { 0x40015, 0x4040 },
  { 0x40035, 0x80 },
  { 0x40055, 0x0 },
  { 0x40075, 0x0 },
  { 0x40016, 0x60a },
  { 0x40036, 0x15 },
  { 0x40056, 0x1200 },
  { 0x40076, 0x0 },
  { 0x40017, 0x61a },
  { 0x40037, 0x15 },
  { 0x40057, 0x1300 },
  { 0x40077, 0x0 },
  { 0x40018, 0x60a },
  { 0x40038, 0x1a },
  { 0x40058, 0x1200 },
  { 0x40078, 0x0 },
  { 0x40019, 0x642 },
  { 0x40039, 0x1a },
  { 0x40059, 0x1300 },
  { 0x40079, 0x0 },
  { 0x4001a, 0x4808 },
  { 0x4003a, 0x880 },
  { 0x4005a, 0x0 },
  { 0x4007a, 0x0 },
  { 0x900aa, 0x0 },
  { 0x900ab, 0x790 },
  { 0x900ac, 0x11a },
  { 0x900ad, 0x8 },
  { 0x900ae, 0x7aa },
  { 0x900af, 0x2a },
  { 0x900b0, 0x10 },
  { 0x900b1, 0x7b2 },
  { 0x900b2, 0x2a },
  { 0x900b3, 0x0 },
  { 0x900b4, 0x7c8 },
  { 0x900b5, 0x109 },
  { 0x900b6, 0x10 },
  { 0x900b7, 0x10 },
  { 0x900b8, 0x109 },
  { 0x900b9, 0x10 },
  { 0x900ba, 0x2a8 },
  { 0x900bb, 0x129 },
  { 0x900bc, 0x8 },
  { 0x900bd, 0x370 },
  { 0x900be, 0x129 },
  { 0x900bf, 0xa },
  { 0x900c0, 0x3c8 },
  { 0x900c1, 0x1a9 },
  { 0x900c2, 0xc },
  { 0x900c3, 0x408 },
  { 0x900c4, 0x199 },
  { 0x900c5, 0x14 },
  { 0x900c6, 0x790 },
  { 0x900c7, 0x11a },
  { 0x900c8, 0x8 },
  { 0x900c9, 0x4 },
  { 0x900ca, 0x18 },
  { 0x900cb, 0xe },
  { 0x900cc, 0x408 },
  { 0x900cd, 0x199 },
  { 0x900ce, 0x8 },
  { 0x900cf, 0x8568 },
  { 0x900d0, 0x108 },
  { 0x900d1, 0x18 },
  { 0x900d2, 0x790 },
  { 0x900d3, 0x16a },
  { 0x900d4, 0x8 },
  { 0x900d5, 0x1d8 },
  { 0x900d6, 0x169 },
  { 0x900d7, 0x10 },
  { 0x900d8, 0x8558 },
  { 0x900d9, 0x168 },
  { 0x900da, 0x1ff8 },
  { 0x900db, 0x85a8 },
  { 0x900dc, 0x1e8 },
  { 0x900dd, 0x50 },
  { 0x900de, 0x798 },
  { 0x900df, 0x16a },
  { 0x900e0, 0x60 },
  { 0x900e1, 0x7a0 },
  { 0x900e2, 0x16a },
  { 0x900e3, 0x8 },
  { 0x900e4, 0x8310 },
  { 0x900e5, 0x168 },
  { 0x900e6, 0x8 },
  { 0x900e7, 0xa310 },
  { 0x900e8, 0x168 },
  { 0x900e9, 0xa },
  { 0x900ea, 0x408 },
  { 0x900eb, 0x169 },
  { 0x900ec, 0x6e },
  { 0x900ed, 0x0 },
  { 0x900ee, 0x68 },
  { 0x900ef, 0x0 },
  { 0x900f0, 0x408 },
  { 0x900f1, 0x169 },
  { 0x900f2, 0x0 },
  { 0x900f3, 0x8310 },
  { 0x900f4, 0x168 },
  { 0x900f5, 0x0 },
  { 0x900f6, 0xa310 },
  { 0x900f7, 0x168 },
  { 0x900f8, 0x1ff8 },
  { 0x900f9, 0x85a8 },
  { 0x900fa, 0x1e8 },
  { 0x900fb, 0x68 },
  { 0x900fc, 0x798 },
  { 0x900fd, 0x16a },
  { 0x900fe, 0x78 },
  { 0x900ff, 0x7a0 },
  { 0x90100, 0x16a },
  { 0x90101, 0x68 },
  { 0x90102, 0x790 },
  { 0x90103, 0x16a },
  { 0x90104, 0x8 },
  { 0x90105, 0x8b10 },
  { 0x90106, 0x168 },
  { 0x90107, 0x8 },
  { 0x90108, 0xab10 },
  { 0x90109, 0x168 },
  { 0x9010a, 0xa },
  { 0x9010b, 0x408 },
  { 0x9010c, 0x169 },
  { 0x9010d, 0x58 },
  { 0x9010e, 0x0 },
  { 0x9010f, 0x68 },
  { 0x90110, 0x0 },
  { 0x90111, 0x408 },
  { 0x90112, 0x169 },
  { 0x90113, 0x0 },
  { 0x90114, 0x8b10 },
  { 0x90115, 0x168 },
  { 0x90116, 0x1 },
  { 0x90117, 0xab10 },
  { 0x90118, 0x168 },
  { 0x90119, 0x0 },
  { 0x9011a, 0x1d8 },
  { 0x9011b, 0x169 },
  { 0x9011c, 0x80 },
  { 0x9011d, 0x790 },
  { 0x9011e, 0x16a },
  { 0x9011f, 0x18 },
  { 0x90120, 0x7aa },
  { 0x90121, 0x6a },
  { 0x90122, 0xa },
  { 0x90123, 0x0 },
  { 0x90124, 0x1e9 },
  { 0x90125, 0x8 },
  { 0x90126, 0x8080 },
  { 0x90127, 0x108 },
  { 0x90128, 0xf },
  { 0x90129, 0x408 },
  { 0x9012a, 0x169 },
  { 0x9012b, 0xc },
  { 0x9012c, 0x0 },
  { 0x9012d, 0x68 },
  { 0x9012e, 0x9 },
  { 0x9012f, 0x0 },
  { 0x90130, 0x1a9 },
  { 0x90131, 0x0 },
  { 0x90132, 0x408 },
  { 0x90133, 0x169 },
  { 0x90134, 0x0 },
  { 0x90135, 0x8080 },
  { 0x90136, 0x108 },
  { 0x90137, 0x8 },
  { 0x90138, 0x7aa },
  { 0x90139, 0x6a },
  { 0x9013a, 0x0 },
  { 0x9013b, 0x8568 },
  { 0x9013c, 0x108 },
  { 0x9013d, 0xb7 },
  { 0x9013e, 0x790 },
  { 0x9013f, 0x16a },
  { 0x90140, 0x1f },
  { 0x90141, 0x0 },
  { 0x90142, 0x68 },
  { 0x90143, 0x8 },
  { 0x90144, 0x8558 },
  { 0x90145, 0x168 },
  { 0x90146, 0xf },
  { 0x90147, 0x408 },
  { 0x90148, 0x169 },
  { 0x90149, 0xd },
  { 0x9014a, 0x0 },
  { 0x9014b, 0x68 },
  { 0x9014c, 0x0 },
  { 0x9014d, 0x408 },
  { 0x9014e, 0x169 },
  { 0x9014f, 0x0 },
  { 0x90150, 0x8558 },
  { 0x90151, 0x168 },
  { 0x90152, 0x8 },
  { 0x90153, 0x3c8 },
  { 0x90154, 0x1a9 },
  { 0x90155, 0x3 },
  { 0x90156, 0x370 },
  { 0x90157, 0x129 },
  { 0x90158, 0x20 },
  { 0x90159, 0x2aa },
  { 0x9015a, 0x9 },
  { 0x9015b, 0x8 },
  { 0x9015c, 0xe8 },
  { 0x9015d, 0x109 },
  { 0x9015e, 0x0 },
  { 0x9015f, 0x8140 },
  { 0x90160, 0x10c },
  { 0x90161, 0x10 },
  { 0x90162, 0x8138 },
  { 0x90163, 0x104 },
  { 0x90164, 0x8 },
  { 0x90165, 0x448 },
  { 0x90166, 0x109 },
  { 0x90167, 0xf },
  { 0x90168, 0x7c0 },
  { 0x90169, 0x109 },
  { 0x9016a, 0x0 },
  { 0x9016b, 0xe8 },
  { 0x9016c, 0x109 },
  { 0x9016d, 0x47 },
  { 0x9016e, 0x630 },
  { 0x9016f, 0x109 },
  { 0x90170, 0x8 },
  { 0x90171, 0x618 },
  { 0x90172, 0x109 },
  { 0x90173, 0x8 },
  { 0x90174, 0xe0 },
  { 0x90175, 0x109 },
  { 0x90176, 0x0 },
  { 0x90177, 0x7c8 },
  { 0x90178, 0x109 },
  { 0x90179, 0x8 },
  { 0x9017a, 0x8140 },
  { 0x9017b, 0x10c },
  { 0x9017c, 0x0 },
  { 0x9017d, 0x478 },
  { 0x9017e, 0x109 },
  { 0x9017f, 0x0 },
  { 0x90180, 0x1 },
  { 0x90181, 0x8 },
  { 0x90182, 0x8 },
  { 0x90183, 0x4 },
  { 0x90184, 0x0 },
  { 0x90006, 0x8 },
  { 0x90007, 0x7c8 },
  { 0x90008, 0x109 },
  { 0x90009, 0x0 },
  { 0x9000a, 0x400 },
  { 0x9000b, 0x106 },
  { 0xd00e7, 0x400 },
  { 0x90017, 0x0 },
  { 0x9001f, 0x2b },
  { 0x90026, 0x69 },
  { 0x400d0, 0x0 },
  { 0x400d1, 0x101 },
  { 0x400d2, 0x105 },
  { 0x400d3, 0x107 },
  { 0x400d4, 0x10f },
  { 0x400d5, 0x202 },
  { 0x400d6, 0x20a },
  { 0x400d7, 0x20b },
  { 0x2003a, 0x2 },
  { 0x200be, 0x3 },
  { 0x2000b, 0x41a },
  { 0x2000c, 0xe9 },
  { 0x2000d, 0x91c },
  { 0x2000e, 0x2c },
  { 0x12000b, 0x20d },
  { 0x12000c, 0x74 },
  { 0x12000d, 0x48e },
  { 0x12000e, 0x2c },
  { 0x22000b, 0xb0 },
  { 0x22000c, 0x27 },
  { 0x22000d, 0x186 },
  { 0x22000e, 0x10 },
  { 0x9000c, 0x0 },
  { 0x9000d, 0x173 },
  { 0x9000e, 0x60 },
  { 0x9000f, 0x6110 },
  { 0x90010, 0x2152 },
  { 0x90011, 0xdfbd },
  { 0x90012, 0x2060 },
  { 0x90013, 0x6152 },
  { 0x20010, 0x5a },
  { 0x20011, 0x3 },
  { 0x120010, 0x5a },
  { 0x120011, 0x3 },
  { 0x40080, 0xe0 },
  { 0x40081, 0x12 },
  { 0x40082, 0xe0 },
  { 0x40083, 0x12 },
  { 0x40084, 0xe0 },
  { 0x40085, 0x12 },
  { 0x140080, 0xe0 },
  { 0x140081, 0x12 },
  { 0x140082, 0xe0 },
  { 0x140083, 0x12 },
  { 0x140084, 0xe0 },
  { 0x140085, 0x12 },
  { 0x240080, 0xe0 },
  { 0x240081, 0x12 },
  { 0x240082, 0xe0 },
  { 0x240083, 0x12 },
  { 0x240084, 0xe0 },
  { 0x240085, 0x12 },
  { 0x400fd, 0xf },
  { 0x400f1, 0xe },
  { 0x10011, 0x1 },
  { 0x10012, 0x1 },
  { 0x10013, 0x180 },
  { 0x10018, 0x1 },
  { 0x10002, 0x6209 },
  { 0x100b2, 0x1 },
  { 0x101b4, 0x1 },
  { 0x102b4, 0x1 },
  { 0x103b4, 0x1 },
  { 0x104b4, 0x1 },
  { 0x105b4, 0x1 },
  { 0x106b4, 0x1 },
  { 0x107b4, 0x1 },
  { 0x108b4, 0x1 },
  { 0x11011, 0x1 },
  { 0x11012, 0x1 },
  { 0x11013, 0x180 },
  { 0x11018, 0x1 },
  { 0x11002, 0x6209 },
  { 0x110b2, 0x1 },
  { 0x111b4, 0x1 },
  { 0x112b4, 0x1 },
  { 0x113b4, 0x1 },
  { 0x114b4, 0x1 },
  { 0x115b4, 0x1 },
  { 0x116b4, 0x1 },
  { 0x117b4, 0x1 },
  { 0x118b4, 0x1 },
  { 0x20089, 0x1 },
  { 0x20088, 0x19 },
  { 0xc0080, 0x0 },
  { 0xd0000, 0x1 },
};

static struct dram_cfg_param ddr_ddrc_cfg[] =
{
  { IMX9_DDRC_SDRAM_CFG, 0x44100001 },
  { IMX9_DDRC_CS0_BNDS, 0x8000ff },
  { IMX9_DDRC_CS1_BNDS, 0x0 },
  { IMX9_DDRC_CS0_CFG, 0x80000512 },
  { IMX9_DDRC_CS1_CFG, 0x0 },
  { IMX9_DDRC_SDRAM_CFG2, 0x1002 },
  { IMX9_DDRC_SDRAM_CFG_3, 0x80 },
  { IMX9_DDRC_UNKNOWN_2, 0x80 },
  { IMX9_DDRC_TX_CFG_1, 0x43b30002 },
  { IMX9_DDRC_UNKNOWN_1, 0x1f1f1f1f },
  { IMX9_DDRC_ERR_EN, 0x0 },
  { IMX9_DDRC_ECC_REG_0, 0x0 },
  { IMX9_DDRC_ECC_REG_1, 0x0 },
  { IMX9_DDRC_ECC_REG_2, 0x0 },
  { IMX9_DDRC_ECC_REG_3, 0x0 },
  { IMX9_DDRC_ECC_REG_4, 0x0 },
  { IMX9_DDRC_ECC_REG_5, 0x0 },
  { IMX9_DDRC_ECC_REG_6, 0x0 },
  { IMX9_DDRC_ECC_REG_7, 0x0 },
};

#endif
